@@ -118,11 +118,7 @@ class TestDrawingAggregate {
             UnsynchronizedByteArrayOutputStream out = UnsynchronizedByteArrayOutputStream.builder().get();
             for (RecordBase rb : aggRecords) {
                 Record r = (org.apache.poi.hssf.record.Record) rb;
-                try {
-                    out.write(r.serialize());
-                } catch (IOException e) {
-                    throw new RuntimeException(e);
-                }
+                out.write(r.serialize());
             }
             return out.toByteArray();
         }
@@ -263,11 +259,7 @@ class TestDrawingAggregate {
         UnsynchronizedByteArrayOutputStream out = UnsynchronizedByteArrayOutputStream.builder().get();
         for (RecordBase rb : records) {
             Record r = (org.apache.poi.hssf.record.Record) rb;
-            try {
-                out.write(r.serialize());
-            } catch (IOException e) {
-                throw new RuntimeException(e);
-            }
+            out.write(r.serialize());
         }
         return out.toByteArray();
     }
